========== Claun help ========== Node entity ================== :Author: Jiri Chadima :Version: 2012/04/18 Description ----------- Node represents one node in the distributed system. Information about nodes is stored in **couchDB** as a JSON document. By using the administration form, you can let the server create the document for you. A full example node document can be seen in the computer.json_ file. Every user has its own document. Some fields in the document are generated by the server. They are described in the appropriate module. Form fields ---------------- The fields in the **node** form are: - **Hostname** - Short name of the host, it is displayed everywhere, ID is generated from it. - **IP address** - IP address of the node. - **Port** - Port where the Claun system runs on the node - **Fully Qualified Domain Name** - Another identification of the node (for example phobos.iim.cz). It should match the name in the node's configuration - **Platforms** - List of supported platforms (i. e. gentoo, win-x86), it is used to idenrtify runtime capabilites of applications. - **Projections** - Projection parameters. If the projection is not selected, the node does not compute that projection. Every projection can have many parameters which identify their configuration when starting the application. They depend on the used framework. For CAVELib, the parameters look like this: +----------+---------------------------------------------------------------+ | Name | Description | +==========+===============================================================+ | xmin | The leftmost position of the X coordinate | +----------+---------------------------------------------------------------+ | xmax | The rightmost position of the X coordinate | +----------+---------------------------------------------------------------+ | ymin | The leftmost position of the Y coordinate | +----------+---------------------------------------------------------------+ | ymax | The rightmost position of the Y coordinate | +----------+---------------------------------------------------------------+ | xscreen | X Screen where the projection will be shown (i. e. 0.0) | +----------+---------------------------------------------------------------+ Typical xmin, xmax and ymin, ymax are 0, 800 and 0, 600. For the square floor projection, Y coordinate is translated by -200 to ymin=-200, ymax=600. These values apply for 800x600 projections. The xscreen settings depends on your XServer setup. - **Connected?** - If the node is currently connected to the cluster (it may be offline for for example maintenance) All the identification fields should be the same as in the node's YAML configuration file. If a node can run multiple platforms, all of them should be configured to use the same network identification. Another used field is the **masterpriority** that you can change in the list view. It means in what order will the nodes be checked for supporting software (like controller software) and considered the master node for the application. .. _computer.json: computer.json .. _configuration.json: configuration.json